@@ -1,31 +1,29 @@
 package Net::Amazon::IAM::AccessKey;
 use Moose;
+extends 'Net::Amazon::IAM::AccessKeyMetadata';
 
-has 'AccessKeyId' => (
-   is       => 'ro',
-   isa      => 'Str',
-   required => 1,
-);
+=head1 NAME
 
-has 'CreateDate' => (
-   is       => 'ro',
-   isa      => 'Str',
-   required => 0,
-);
+Net::Amazon::IAM::AccessKey 
+
+=head1 DESCRIPTION
+
+A class representing a IAM AccessKey
+This class extends Net::Amazon::IAM::AccessKeyMetadata
+
+=head1 ATTRIBUTES
+
+=over
+
+=item SecretAccessKey (required)
+
+The secret key used to sign requests.
+
+=back
+
+=cut
 
 has 'SecretAccessKey' => (
-   is       => 'ro',
-   isa      => 'Str',
-   required => 0,
-);
-
-has 'Status' => (
-   is       => 'ro',
-   isa      => 'Str',
-   required => 0,
-);
-
-has 'UserName' => (
    is       => 'ro',
    isa      => 'Str',
    required => 1,
