@@ -1,6 +1,26 @@
 package Net::Amazon::IAM::AccessKeysList;
 use Moose;
 
+=head1 NAME
+
+Net::Amazon::IAM::AccessKeysList
+
+=head1 DESCRIPTION
+
+A class representing a IAM Access Keys List
+
+=head1 ATTRIBUTES
+
+=over
+
+=item Keys (required)
+
+Array of Net::Amazon::IAM::AccessKeyMetadata
+
+=back
+
+=cut
+
 has 'Keys' => (
    is       => 'ro',
    isa      => 'Maybe[ArrayRef[Net::Amazon::IAM::AccessKeyMetadata]]',
